﻿using Infragistics.Controls.Charts;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Runtime.CompilerServices;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Windows.Threading;

namespace StackedSeriesBrushSample
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        DispatcherTimer Dtimer = new DispatcherTimer();
        EnergyDataSource eds;
        public MainWindow()
        {
            InitializeComponent();
            eds = this.xDataChart.Resources["energyProdData"] as EnergyDataSource;
            Dtimer.Interval = new TimeSpan(10000000);

            Dtimer.Tick += new EventHandler(Dtimer_Tick);

            Dtimer.Start();
        }

        protected void Dtimer_Tick(object s, EventArgs args)
        {
            EnergyProduction production;
            var d = RandomNumberBetween(0, 300);
            for (int i = 0; i < eds.Count; i++)
            {                
                production = eds[i] as EnergyProduction;
                production.Coal = d;

                if (d <= 100)
                {                   
                    eds.FragmentBrush = new SolidColorBrush(Colors.Red);
                }
                else if (d < 250 && d > 100)
                {
                    eds.FragmentBrush = new SolidColorBrush(Colors.Yellow);
                }
                else if (d < 500 && d > 250.0)
                {
                    eds.FragmentBrush = new SolidColorBrush(Colors.Green);
                }
               
                
            }


        }

        private static readonly Random random = new Random();

        private static double RandomNumberBetween(double minValue, double maxValue)
        {
            var next = random.NextDouble();

            return minValue + (next * (maxValue - minValue));
        }
    }

    public class EnergyProduction : INotifyPropertyChanged
    {
       
        public string Country { get; set; }
        public string Region { get; set; }
        public string Year { get; set; }

        // Non-Renewable Energy Sources
        public double Nuclear { get; set; }

        private double name;
        public double Coal {
            get { return name; }
            set
            {
                name = value;
                // Call OnPropertyChanged whenever the property is updated
                OnPropertyChanged();
            }
        }
        public double Oil { get; set; }
        public double Gas { get; set; }
        // Renewable Energy Sources
        public double Hydro { get; set; }
        public double GeoThermal { get; set; }
        public double Solar { get; set; }
        public double Wind { get; set; }

        public double Total { get { return Renewable + NonRenewable; } }
        public double Renewable { get { return Hydro + GeoThermal + Wind + Solar; } }
        public double NonRenewable { get { return Coal + Oil + Gas + Nuclear; } }

        // Create the OnPropertyChanged method to raise the event
        // The calling member's name will be used as the parameter.
        public event PropertyChangedEventHandler PropertyChanged;

        protected void OnPropertyChanged([CallerMemberName] string name = null)
        {
            PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(name));
        }
    }

    public class EnergyDataSource : List<EnergyProduction>, INotifyPropertyChanged
    {
        public EnergyDataSource()
        {
            this.Add(new EnergyProduction { Region = "America", Country = "CAN", Coal = 400, Oil = 100, Gas = 175, Nuclear = 225, Hydro = 350 });
            this.Add(new EnergyProduction { Region = "Asia", Country = "CHN", Coal = 925, Oil = 200, Gas = 350, Nuclear = 400, Hydro = 625 });
            this.Add(new EnergyProduction { Region = "Europe", Country = "RUS", Coal = 550, Oil = 200, Gas = 250, Nuclear = 475, Hydro = 425 });
            this.Add(new EnergyProduction { Region = "Asia", Country = "AUS", Coal = 450, Oil = 100, Gas = 150, Nuclear = 175, Hydro = 350 });
            this.Add(new EnergyProduction { Region = "America", Country = "USA", Coal = 800, Oil = 250, Gas = 475, Nuclear = 575, Hydro = 750 });
            this.Add(new EnergyProduction { Region = "Europe", Country = "FRA", Coal = 375, Oil = 150, Gas = 350, Nuclear = 275, Hydro = 325 });
        }

        private SolidColorBrush brush;
        public SolidColorBrush FragmentBrush
        {
            get { return brush; }
            set
            {
                brush = value;
                OnPropertyChanged();
                // Call OnPropertyChanged whenever the property is updated

            }
        }

        // Create the OnPropertyChanged method to raise the event
        // The calling member's name will be used as the parameter.
        public event PropertyChangedEventHandler PropertyChanged;

        protected void OnPropertyChanged([CallerMemberName] string name = null)
        {
            PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(name));
        }
    }

}
